@@ -36,16 +36,44 @@ private Q_SLOTS:
     void initTestCase()
     {
         QStandardPaths::setTestModeEnabled(true);
-        qputenv("KDE_FORK_SLAVES", "yes"); // to avoid a runtime dependency on klauncher
 #ifdef Q_OS_UNIX
         m_umask = ::umask(0);
         ::umask(m_umask);
 #endif
         QVERIFY(m_tmpDir.isValid());
+
+        // These have to be created here before KNewFileMenuSingleton is created,
+        // otherwise they wouldn't be picked up
+        QDir dir;
+        m_xdgConfigDir = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
+        QVERIFY(dir.mkpath(m_xdgConfigDir));
+        QFile userDirs(m_xdgConfigDir + "/user-dirs.dirs");
+        QVERIFY(userDirs.open(QIODevice::WriteOnly));
+        const QString templDir = "XDG_TEMPLATES_DIR=\"" + m_xdgConfigDir + "/test-templates/\"\n";
+        userDirs.write(templDir.toLocal8Bit());
+        userDirs.close();
+
+        // Different location than what KNewFileMenuPrivate::slotFillTemplates() checks by default
+        const QString loc = m_xdgConfigDir + '/' + "test-templates/";
+        QVERIFY(dir.mkpath(loc));
+
+        QFile templ(m_xdgConfigDir + "/test-templates" + "/test-text.desktop");
+        QVERIFY(templ.open(QIODevice::WriteOnly));
+        const QByteArray contents =
+            "[Desktop Entry]\n"
+            "Name=Custom...\n"
+            "Type=Link\n"
+            "URL=TestTextFile.txt\n"
+            "Icon=text-plain\n";
+
+        templ.write(contents);
+        templ.close();
     }
 
     void cleanupTestCase()
     {
+        QFile::remove(m_xdgConfigDir + "/user-dirs.dirs");
+        QDir(m_xdgConfigDir + "/test-templates").removeRecursively();
     }
 
     // Ensure that we can use storedPut() with a qrc file as input
@@ -95,7 +123,7 @@ private Q_SLOTS:
         QTest::newRow("text file with jpeg extension") << "Text File"
                                                        << "Text File.txt"
                                                        << "foo.jpg"
-                                                       << "foo.jpg.txt";
+                                                       << "foo.jpg"; // You get what you typed
         QTest::newRow("html file") << "HTML File"
                                    << "HTML File.html"
                                    << "foo.html"
@@ -106,13 +134,13 @@ private Q_SLOTS:
                                           << "tmp_link.desktop";
         QTest::newRow("url desktop file no extension") << "Link to Location "
                                                        << ""
-                                                       << "tmp_link"
-                                                       << "tmp_link";
+                                                       << "tmp_link1"
+                                                       << "tmp_link1.desktop";
         QTest::newRow("url desktop file .pl extension") << "Link to Location "
                                                         << ""
                                                         << "tmp_link.pl"
                                                         << "tmp_link.pl.desktop";
-        QTest::newRow("symlink") << "Basic Link"
+        QTest::newRow("symlink") << "Link to File"
                                  << ""
                                  << "thelink"
                                  << "thelink";
@@ -158,16 +186,22 @@ private Q_SLOTS:
         QFETCH(QString, expectedFilename);
 
         QWidget parentWidget;
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 100)
         KActionCollection coll(this, QStringLiteral("foo"));
         KNewFileMenu menu(&coll, QStringLiteral("the_action"), this);
+#else
+        KNewFileMenu menu(this);
+#endif
         menu.setModal(false);
         menu.setParentWidget(&parentWidget);
         menu.setSelectDirWhenAlreadyExist(true);
-        QList<QUrl> lst;
-        lst << QUrl::fromLocalFile(m_tmpDir.path());
-        menu.setPopupFiles(lst);
+        menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
         menu.checkUpToDate();
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 100)
         QAction *action = coll.action(QStringLiteral("the_action"));
+#else
+        QAction *action = &menu;
+#endif
         QVERIFY(action);
         QAction *textAct = nullptr;
         const QList<QAction *> actionsList = action->menu()->actions();
@@ -202,7 +236,7 @@ private Q_SLOTS:
             nauiDialog->setSuggestedName(typedFilename);
             nauiDialog->setSuggestedUrl(QUrl(QStringLiteral("file:///etc")));
         } else if (KPropertiesDialog *propsDialog = qobject_cast<KPropertiesDialog *>(dialog)) {
-            QLineEdit *lineEdit = propsDialog->findChild<QLineEdit *>(QStringLiteral("KFilePropsPlugin::nameLineEdit"));
+            QLineEdit *lineEdit = propsDialog->findChild<QLineEdit *>(QStringLiteral("fileNameLineEdit"));
             QVERIFY(lineEdit);
             QCOMPARE(lineEdit->text(), expectedDefaultFilename);
             lineEdit->setText(typedFilename);
@@ -246,7 +280,7 @@ private Q_SLOTS:
             }
             emittedUrl = spy.at(0).at(0).toUrl();
             QVERIFY(QFile::exists(path));
-            if (actionText != QLatin1String("Basic Link")) {
+            if (actionText != QLatin1String("Link to File")) {
                 QFile file(path);
                 QVERIFY(file.open(QIODevice::ReadOnly));
                 const QByteArray contents = file.readAll();
@@ -258,8 +292,34 @@ private Q_SLOTS:
         QCOMPARE(emittedUrl.toLocalFile(), path);
     }
 
+    void testParsingUserDirs()
+    {
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 100)
+        KActionCollection coll(this, QStringLiteral("foo"));
+        KNewFileMenu menu(&coll, QStringLiteral("the_action"), this);
+#else
+        KNewFileMenu menu(this);
+#endif
+        menu.setWorkingDirectory(QUrl::fromLocalFile(m_tmpDir.path()));
+        menu.checkUpToDate();
+#if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(5, 100)
+        QAction *action = coll.action(QStringLiteral("the_action"));
+#else
+        QAction *action = &menu;
+#endif
+        const auto list = action->menu()->actions();
+        auto it = std::find_if(list.cbegin(), list.cend(), [](QAction *act) {
+            return act->text().contains("Custom");
+        });
+        QVERIFY(it != list.cend());
+        // There is a separator between system-wide templates and the ones
+        // from the user's home
+        QVERIFY((*--it)->isSeparator());
+    }
+
 private:
     QTemporaryDir m_tmpDir;
+    QString m_xdgConfigDir;
 #ifdef Q_OS_UNIX
     mode_t m_umask;
 #endif
