@@ -26,7 +26,6 @@ class KUrlRequesterTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
-    void initTestCase();
     void testUrlRequester();
     void testComboRequester();
     void testComboRequester_data();
@@ -57,11 +56,6 @@ static KFileWidget *findFileWidget()
     return (widgets.count() == 1) ? widgets.first() : nullptr;
 }
 
-void KUrlRequesterTest::initTestCase()
-{
-    qputenv("KDE_FORK_SLAVES", "yes");
-}
-
 void KUrlRequesterTest::testUrlRequester()
 {
     KUrlRequester req;
