@@ -21,9 +21,6 @@ QTEST_MAIN(PrivilegeJobTest)
 
 void PrivilegeJobTest::initTestCase()
 {
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
-
     cleanupTestCase();
     homeTmpDir();
     m_testFilePath = homeTmpDir() + "testfile";
@@ -46,7 +43,8 @@ void PrivilegeJobTest::privilegeChmod()
     QVERIFY(newPerm != origPerm);
     // Remove search permission
     QVERIFY(QFile::setPermissions(homeTmpDir(), QFileDevice::ReadOwner));
-    KFileItemList items; items << item;
+    KFileItemList items;
+    items << item;
     KIO::Job *job = KIO::chmod(items, newPerm, S_IWGRP, QString(), QString(), false, KIO::HideProgressInfo);
     job->addMetaData("UnitTesting", "true");
     job->setUiDelegate(nullptr);
