@@ -1,41 +1,28 @@
 // -*- c++ -*-
-/* This file is part of the KDE libraries
-    Copyright 2000       Stephan Kulow <coolo@kde.org>
-    Copyright 2000-2006  David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2006 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_COPYJOB_H
 #define KIO_COPYJOB_H
 
+#include <QDateTime>
 #include <QObject>
 #include <QStringList>
-#include <QDateTime>
 #include <QUrl>
 
+#include "job_base.h"
 #include "kiocore_export.h"
 #include <kio/global.h> // filesize_t
-#include "job_base.h"
 
 class QTimer;
 
 namespace KIO
 {
-
 /// @internal
 /// KF6 TODO: move to .cpp and remove aboutToCreate signal
 struct CopyInfo {
@@ -65,7 +52,6 @@ class CopyJobPrivate;
  */
 class KIOCORE_EXPORT CopyJob : public Job
 {
-
     Q_OBJECT
 
 public:
@@ -146,8 +132,14 @@ Q_SIGNALS:
      * Emitted when the total number of files is known.
      * @param job the job that emitted this signal
      * @param files the total number of files
+     *
+     * @deprecated since 5.72, up to Frameworks versions <= 5.79, use the KJob::totalAmount(KJob *, KJob::Unit, qulonglong)
+     * signal, starting from 5.80 use the KJob::totalAmountChanged(KJob *, KJob::Unit, qulonglong) signal instead.
      */
-    KIOCORE_DEPRECATED_VERSION(5, 72, "Use KJob::totalAmount instead. This one is not emitted")
+    KIOCORE_DEPRECATED_VERSION(5,
+                               72,
+                               "Up to Frameworks versions <= 5.79, use the KJob::totalAmount(KJob *, KJob::Unit, qulonglong) signal, starting from 5.80 use "
+                               "the KJob::totalAmountChanged(KJob *, KJob::Unit, qulonglong) signal instead.")
     QT_MOC_COMPAT void totalFiles(KJob *job, unsigned long files);
 #endif
 
@@ -156,8 +148,14 @@ Q_SIGNALS:
      * Emitted when the total number of directories is known.
      * @param job the job that emitted this signal
      * @param dirs the total number of directories
+     *
+     * @deprecated since 5.72, up to Frameworks versions <= 5.79, use the KJob::totalAmount(KJob *, KJob::Unit, qulonglong) signal, starting from 5.80 use
+     * KJob::totalAmountChanged(KJob *, KJob::Unit, qulonglong) signal instead.
      */
-    KIOCORE_DEPRECATED_VERSION(5, 72, "Use KJob::totalAmount instead. This one is not emitted")
+    KIOCORE_DEPRECATED_VERSION(5,
+                               72,
+                               "Up to Frameworks versions <= 5.79, use the KJob::totalAmount(KJob *, KJob::Unit, qulonglong) signal, starting from 5.80 use "
+                               "KJob::totalAmountChanged(KJob *, KJob::Unit, qulonglong) signal instead.")
     QT_MOC_COMPAT void totalDirs(KJob *job, unsigned long dirs);
 #endif
 
@@ -250,7 +248,7 @@ Q_SIGNALS:
      * @param from the source URL
      * @param to the destination URL
      * @param mtime the modification time of the source file, hopefully set on the destination file
-     * too (when the kioslave supports it).
+     * too (when the KIO worker supports it).
      * @param directory indicates whether a file or directory was successfully copied/moved.
      *                  true for a directory, false for file
      * @param renamed indicates that the destination URL was created using a
@@ -275,8 +273,6 @@ protected:
     void emitResult();
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void sourceStated(const KIO::UDSEntry &entry, const QUrl &sourceUrl))
-
     Q_DECLARE_PRIVATE(CopyJob)
 };
 
