@@ -5,18 +5,20 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "global.h"
 #include "directorysizejob.h"
+#include "global.h"
 #include "listjob.h"
-#include <kio/jobuidelegatefactory.h>
 #include <QDebug>
 #include <QTimer>
+#include <kio/jobuidelegatefactory.h>
 
 #include "job_p.h"
 
+#include <set>
+
 namespace KIO
 {
-class DirectorySizeJobPrivate: public KIO::JobPrivate
+class DirectorySizeJobPrivate : public KIO::JobPrivate
 {
 public:
     DirectorySizeJobPrivate()
@@ -39,7 +41,7 @@ public:
     KIO::filesize_t m_totalSubdirs;
     KFileItemList m_lstItems;
     int m_currentItem;
-    QHash<long, QSet<long> > m_visitedInodes; // device -> set of inodes
+    QHash<long, std::set<long>> m_visitedInodes; // device -> set of inodes
 
     void startNextJob(const QUrl &url);
     void slotEntries(KIO::Job *, const KIO::UDSEntryList &);
@@ -61,7 +63,9 @@ public:
         DirectorySizeJobPrivate *d = new DirectorySizeJobPrivate(lstItems);
         DirectorySizeJob *job = new DirectorySizeJob(*d);
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
-        QTimer::singleShot(0, job, SLOT(processNextItem()));
+        QTimer::singleShot(0, job, [d]() {
+            d->processNextItem();
+        });
         return job;
     }
 };
@@ -102,35 +106,35 @@ void DirectorySizeJobPrivate::processNextItem()
         // qDebug() << item;
         if (!item.isLink()) {
             if (item.isDir()) {
-                //qDebug() << "dir -> listing";
-                startNextJob(item.url());
+                // qDebug() << "dir -> listing";
+                startNextJob(item.targetUrl());
                 return; // we'll come back later, when this one's finished
             } else {
                 m_totalSize += item.size();
                 m_totalFiles++;
-                //qDebug() << "file -> " << m_totalSize;
+                // qDebug() << "file -> " << m_totalSize;
             }
         } else {
             m_totalFiles++;
         }
     }
-    //qDebug() << "finished";
+    // qDebug() << "finished";
     q->emitResult();
 }
 
 void DirectorySizeJobPrivate::startNextJob(const QUrl &url)
 {
     Q_Q(DirectorySizeJob);
-    //qDebug() << url;
+    // qDebug() << url;
     KIO::ListJob *listJob = KIO::listRecursive(url, KIO::HideProgressInfo);
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
     // TODO KF6: remove legacy details code path
     listJob->addMetaData(QStringLiteral("details"), QStringLiteral("3"));
 #endif
-    listJob->addMetaData(QStringLiteral("statDetails"),
-                         QString::number(KIO::StatBasic | KIO::StatResolveSymlink | KIO::StatInode));
-    q->connect(listJob, &KIO::ListJob::entries,
-               q, [this](KIO::Job* job, const KIO::UDSEntryList &list) { slotEntries(job, list); });
+    listJob->addMetaData(QStringLiteral("statDetails"), QString::number(KIO::StatBasic | KIO::StatResolveSymlink | KIO::StatInode));
+    q->connect(listJob, &KIO::ListJob::entries, q, [this](KIO::Job *job, const KIO::UDSEntryList &list) {
+        slotEntries(job, list);
+    });
     q->addSubjob(listJob);
 }
 
@@ -139,24 +143,23 @@ void DirectorySizeJobPrivate::slotEntries(KIO::Job *, const KIO::UDSEntryList &l
     KIO::UDSEntryList::ConstIterator it = list.begin();
     const KIO::UDSEntryList::ConstIterator end = list.end();
     for (; it != end; ++it) {
-
         const KIO::UDSEntry &entry = *it;
 
         const long device = entry.numberValue(KIO::UDSEntry::UDS_DEVICE_ID, 0);
         if (device && !entry.isLink()) {
             // Hard-link detection (#67939)
             const long inode = entry.numberValue(KIO::UDSEntry::UDS_INODE, 0);
-            QSet<long> &visitedInodes = m_visitedInodes[device];  // find or insert
-            if (visitedInodes.contains(inode)) {
+            std::set<long> &visitedInodes = m_visitedInodes[device]; // find or insert
+            const auto [it, isNewInode] = visitedInodes.insert(inode);
+            if (!isNewInode) {
                 continue;
             }
-            visitedInodes.insert(inode);
         }
         const KIO::filesize_t size = entry.numberValue(KIO::UDSEntry::UDS_SIZE, 0);
         const QString name = entry.stringValue(KIO::UDSEntry::UDS_NAME);
         if (name == QLatin1Char('.')) {
             m_totalSize += size;
-            //qDebug() << "'.': added" << size << "->" << m_totalSize;
+            // qDebug() << "'.': added" << size << "->" << m_totalSize;
         } else if (name != QLatin1String("..")) {
             if (!entry.isLink()) {
                 m_totalSize += size;
@@ -166,7 +169,7 @@ void DirectorySizeJobPrivate::slotEntries(KIO::Job *, const KIO::UDSEntryList &l
             } else {
                 m_totalSubdirs++;
             }
-            //qDebug() << name << ":" << size << "->" << m_totalSize;
+            // qDebug() << name << ":" << size << "->" << m_totalSize;
         }
     }
 }
@@ -174,7 +177,7 @@ void DirectorySizeJobPrivate::slotEntries(KIO::Job *, const KIO::UDSEntryList &l
 void DirectorySizeJob::slotResult(KJob *job)
 {
     Q_D(DirectorySizeJob);
-    //qDebug() << d->m_totalSize;
+    // qDebug() << d->m_totalSize;
     removeSubjob(job);
     if (d->m_currentItem < d->m_lstItems.count()) {
         d->processNextItem();
@@ -187,13 +190,13 @@ void DirectorySizeJob::slotResult(KJob *job)
     }
 }
 
-//static
+// static
 DirectorySizeJob *KIO::directorySize(const QUrl &directory)
 {
     return DirectorySizeJobPrivate::newJob(directory); // useless - but consistent with other jobs
 }
 
-//static
+// static
 DirectorySizeJob *KIO::directorySize(const KFileItemList &lstItems)
 {
     return DirectorySizeJobPrivate::newJob(lstItems);
