@@ -9,15 +9,15 @@
 #define KFILEITEM_H
 
 #include "kiocore_export.h"
-#include <kio/global.h>
-#include <kacl.h>
-#include <kio/udsentry.h>
 #include <QDateTime>
-#include <QUrl>
 #include <QFile>
+#include <QUrl>
+#include <kacl.h>
+#include <kio/global.h>
+#include <kio/udsentry.h>
 
-#include <QMimeType>
 #include <QList>
+#include <QMimeType>
 #include <qplatformdefs.h>
 
 class KFileItemPrivate;
@@ -28,12 +28,43 @@ class KFileItemPrivate;
  * A KFileItem is a generic class to handle a file, local or remote.
  * In particular, it makes it easier to handle the result of KIO::listDir
  * (UDSEntry isn't very friendly to use).
- * It includes many file attributes such as mimetype, icon, text, mode, link...
+ * It includes many file attributes such as MIME type, icon, text, mode, link...
  *
  * KFileItem is implicitly shared, i.e. it can be used as a value and copied around at almost no cost.
  */
 class KIOCORE_EXPORT KFileItem
 {
+    Q_GADGET
+
+    Q_PROPERTY(QUrl url READ url WRITE setUrl)
+    Q_PROPERTY(QString user READ user)
+    Q_PROPERTY(QString group READ group)
+    Q_PROPERTY(bool isLink READ isLink)
+    Q_PROPERTY(bool isDir READ isDir)
+    Q_PROPERTY(bool isFile READ isFile)
+    Q_PROPERTY(bool isReadable READ isReadable)
+    Q_PROPERTY(bool isWritable READ isWritable)
+    Q_PROPERTY(bool isHidden READ isHidden)
+    Q_PROPERTY(bool isSlow READ isSlow)
+    Q_PROPERTY(bool isDesktopFile READ isDesktopFile)
+    Q_PROPERTY(QString linkDest READ linkDest)
+    Q_PROPERTY(QUrl targetUrl READ targetUrl)
+    Q_PROPERTY(QString localPath READ localPath WRITE setLocalPath)
+    Q_PROPERTY(bool isLocalFile READ isLocalFile)
+    Q_PROPERTY(QString text READ text)
+    Q_PROPERTY(QString name READ name WRITE setName)
+    Q_PROPERTY(QString mimetype READ mimetype)
+    Q_PROPERTY(QMimeType determineMimeType READ determineMimeType)
+    Q_PROPERTY(QMimeType currentMimeType READ currentMimeType)
+    Q_PROPERTY(bool isFinalIconKnown READ isFinalIconKnown)
+    Q_PROPERTY(bool isMimeTypeKnown READ isMimeTypeKnown)
+    Q_PROPERTY(QString mimeComment READ mimeComment)
+    Q_PROPERTY(QString iconName READ iconName)
+    Q_PROPERTY(QStringList overlays READ overlays)
+    Q_PROPERTY(QString comment READ comment)
+    Q_PROPERTY(QString getStatusBarInfo READ getStatusBarInfo)
+    Q_PROPERTY(bool isRegularFile READ isRegularFile)
+
 public:
     enum { Unknown = static_cast<mode_t>(-1) };
 
@@ -47,14 +78,16 @@ public:
         // warning: don't change without looking at the Private class
         ModificationTime = 0,
         AccessTime = 1,
-        CreationTime = 2
-                       //ChangeTime
+        CreationTime = 2,
+        // ChangeTime
     };
+    Q_ENUM(FileTimes)
 
     enum MimeTypeDetermination {
         NormalMimeTypeDetermination = 0,
-        SkipMimeTypeFromContent
+        SkipMimeTypeFromContent,
     };
+    Q_ENUM(MimeTypeDetermination)
 
     /**
      * Null KFileItem. Doesn't represent any file, only exists for convenience.
@@ -67,7 +100,7 @@ public:
      *
      * @param entry the KIO entry used to get the file, contains info about it
      * @param itemOrDirUrl the URL of the item or of the directory containing this item (see urlIsDirectory).
-     * @param delayedMimeTypes specifies if the mimetype of the given
+     * @param delayedMimeTypes specifies if the MIME type of the given
      *       URL should be determined immediately or on demand.
      *       See the bool delayedMimeTypes in the KDirLister constructor.
      * @param urlIsDirectory specifies if the url is just the directory of the
@@ -76,9 +109,7 @@ public:
      * When creating KFileItems out of the UDSEntry emitted by a KIO list job,
      * use KFileItem(entry, listjob->url(), delayedMimeTypes, true);
      */
-    KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl,
-              bool delayedMimeTypes = false,
-              bool urlIsDirectory = false);
+    KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl, bool delayedMimeTypes = false, bool urlIsDirectory = false);
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -91,28 +122,27 @@ public:
      * Set to KFileItem::Unknown if you don't know the mode or the permission.
      * @param url the file url
      *
-     * @param delayedMimeTypes specify if the mimetype of the given URL
+     * @param delayedMimeTypes specify if the MIME type of the given URL
      *       should be determined immediately or on demand
      * @deprecated since 5.0. Most callers gave Unknown for mode and permissions,
      * so just port to KFileItem(url) and setDelayedMimeTypes(true) if necessary.
      */
     KIOCORE_DEPRECATED_VERSION(5, 0, "See API docs")
-    KFileItem(mode_t mode, mode_t permissions, const QUrl &url,
-              bool delayedMimeTypes = false);
+    KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool delayedMimeTypes = false);
 #endif
 
     /**
-     * Creates an item representing a file, for which the mimetype is already known.
+     * Creates an item representing a file, for which the MIME type is already known.
      * @param url the file url
-     * @param mimeType the name of the file's mimetype
+     * @param mimeType the name of the file's MIME type
      * @param mode the mode (S_IFDIR...)
      */
     KFileItem(const QUrl &url, const QString &mimeType = QString(), mode_t mode = KFileItem::Unknown); // KF6 TODO: explicit!
 
     /**
-     * Creates an item representing a file, with the option of skipping mime type determination.
+     * Creates an item representing a file, with the option of skipping MIME type determination.
      * @param url the file url
-     * @param mimeTypeDetermination the mode of determining the mime type:
+     * @param mimeTypeDetermination the mode of determining the MIME type:
      *       NormalMimeTypeDetermination by content if local file, i.e. access the file,
      *                                   open and read part of it;
      *                                   by QMimeDatabase::MatchMode::MatchExtension if not local.
@@ -126,7 +156,7 @@ public:
     /**
      * Copy constructor
      */
-    KFileItem(const KFileItem&);
+    KFileItem(const KFileItem &);
 
     /**
      * Destructor
@@ -137,18 +167,18 @@ public:
      * Move constructor
      * @since 5.43
      */
-    KFileItem(KFileItem&&);
+    KFileItem(KFileItem &&);
 
     /**
      * Copy assignment
      */
-    KFileItem& operator=(const KFileItem&);
+    KFileItem &operator=(const KFileItem &);
 
     /**
      * Move assignment
      * @since 5.43
      */
-    KFileItem& operator=(KFileItem&&);
+    KFileItem &operator=(KFileItem &&);
 
     /**
      * Throw away and re-read (for local files) all information about the file.
@@ -157,14 +187,14 @@ public:
     void refresh();
 
     /**
-     * Re-reads mimetype information.
-     * This is called when the mimetype database changes.
+     * Re-reads MIME type information.
+     * This is called when the MIME type database changes.
      */
     void refreshMimeType();
 
     /**
-     * Sets mimetype determination to be immediate or on demand.
-     * Call this after the constructor, and before using any mimetype-related method.
+     * Sets MIME type determination to be immediate or on demand.
+     * Call this after the constructor, and before using any MIME-type-related method.
      * @since 5.0
      */
     void setDelayedMimeTypes(bool b);
@@ -192,7 +222,7 @@ public:
     void setLocalPath(const QString &path);
 
     /**
-     * Sets the item's name (i.e. the filename).
+     * Sets the item's name (i.e.\ the filename).
      * This is automatically done by setUrl, to set the name from the URL's fileName().
      * This method is provided for some special cases like relative paths as names (KFindPart)
      * @param name the item's name
@@ -297,7 +327,7 @@ public:
 
     /**
      * Checks whether the file is a readable local .desktop file,
-     * i.e. a file whose path can be given to KDesktopFile
+     * i.e.\ a file whose path can be given to KDesktopFile
      * @return true if the file is a desktop file.
      * @since 4.1
      */
@@ -311,7 +341,7 @@ public:
 
     /**
      * Returns the target url of the file, which is the same as url()
-     * in cases where the slave doesn't specify UDS_TARGET_URL
+     * in cases where the worker doesn't specify UDS_TARGET_URL
      * @return the target url.
      * @since 4.1
      */
@@ -347,7 +377,7 @@ public:
      * @return the time asked for, QDateTime() if not available
      * @see timeString()
      */
-    QDateTime time(FileTimes which) const;
+    Q_INVOKABLE QDateTime time(FileTimes which) const;
 
     /**
      * Requests the modification, access or creation time as a string, depending
@@ -356,7 +386,7 @@ public:
      * @returns a formatted string of the requested time.
      * @see time
      */
-    QString timeString(FileTimes which = ModificationTime) const;
+    Q_INVOKABLE QString timeString(FileTimes which = ModificationTime) const;
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
     KIOCORE_DEPRECATED_VERSION(4, 0, "Use KFileItem::timeString(FileTimes)")
@@ -386,25 +416,25 @@ public:
     QString name(bool lowerCase = false) const;
 
     /**
-     * Returns the mimetype of the file item.
+     * Returns the MIME type of the file item.
      * If @p delayedMimeTypes was used in the constructor, this will determine
-     * the mimetype first. Equivalent to determineMimeType()->name()
-     * @return the mime type of the file
+     * the MIME type first. Equivalent to determineMimeType()->name()
+     * @return the MIME type of the file
      */
     QString mimetype() const;
 
     /**
-     * Returns the mimetype of the file item.
+     * Returns the MIME type of the file item.
      * If delayedMimeTypes was used in the constructor, this will determine
-     * the mimetype first.
-     * @return the mime type
+     * the MIME type first.
+     * @return the MIME type
      */
     QMimeType determineMimeType() const;
 
     /**
-     * Returns the currently known mimetype of the file item.
-     * This will not try to determine the mimetype if unknown.
-     * @return the known mime type
+     * Returns the currently known MIME type of the file item.
+     * This will not try to determine the MIME type if unknown.
+     * @return the known MIME type
      */
     QMimeType currentMimeType() const;
 
@@ -415,9 +445,9 @@ public:
     bool isFinalIconKnown() const;
 
     /**
-     * @return true if we have determined the mimetype of this file already,
+     * @return true if we have determined the MIME type of this file already,
      * i.e. if determineMimeType() will be fast. Otherwise it will have to
-     * find what the mimetype is, which is a possibly slow operation; usually
+     * find what the MIME type is, which is a possibly slow operation; usually
      * this is delayed until necessary.
      */
     bool isMimeTypeKnown() const;
@@ -431,7 +461,7 @@ public:
 
     /**
      * Returns the full path name to the icon that represents
-     * this mime type.
+     * this MIME type.
      * @return iconName the name of the file's icon
      */
     QString iconName() const;
@@ -454,7 +484,7 @@ public:
 
     /**
      * Returns the string to be displayed in the statusbar,
-     * e.g. when the mouse is over this item
+     * e.g.\ when the mouse is over this item.
      * @return the status bar information
      */
     QString getStatusBarInfo() const;
@@ -535,18 +565,58 @@ public:
 #endif
 
     /**
-     * Tries to give a local URL for this file item if possible.
-     * The given boolean indicates if the returned url is local or not.
-     * \since 4.6
+     * Tries to return a local URL for this file item if possible.
+     * If @p local is not null, it will be set to @c true if the returned url is local,
+     * @c false otherwise.
+     *
+     * Example:
+     * @code
+     * bool isLocal = false;
+     * KFileItem item;
+     * const QUrl url = item.mostLocalUrl(&isLocal);
+     * if (isLocal) {
+     *    // Use url
+     * }
+     * @endcode
+     *
+     * @since 4.6
      */
     QUrl mostLocalUrl(bool *local = nullptr) const;
 
+    struct MostLocalUrlResult {
+        QUrl url;
+        bool local;
+    };
+
+    /**
+     * Returns a MostLocalUrlResult, with the local Url for this item if possible
+     * (otherwise an empty Url), and a bool that is set to @c true if this Url
+     * does represent a local file otherwise @c false.
+     *
+     * Basically this is an alternative to mostLocalUrl(bool*), that does not use an
+     * output parameter.
+     *
+     * Example:
+     * @code
+     * KFileItem item;
+     * const MostLocalUrlResult result = item.isMostLocalUrl();
+     * if (result.local) { // A local file
+     *    // Use result.url
+     * }
+     * @endcode
+     * @since 5.84
+     */
+    MostLocalUrlResult isMostLocalUrl() const;
+
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0 add '&' in front of your boolean argument
      */
     KIOCORE_DEPRECATED_VERSION(5, 0, "Use KFileItem::mostLocalUrl(bool *)")
-    QUrl mostLocalUrl(bool &local) const { return mostLocalUrl(&local); }
+    QUrl mostLocalUrl(bool &local) const
+    {
+        return mostLocalUrl(&local);
+    }
 #endif
 
     /**
@@ -563,8 +633,8 @@ private:
     void setHidden();
 
 private:
-    KIOCORE_EXPORT friend QDataStream &operator<< (QDataStream &s, const KFileItem &a);
-    KIOCORE_EXPORT friend QDataStream &operator>> (QDataStream &s, KFileItem &a);
+    KIOCORE_EXPORT friend QDataStream &operator<<(QDataStream &s, const KFileItem &a);
+    KIOCORE_EXPORT friend QDataStream &operator>>(QDataStream &s, KFileItem &a);
 
     friend class KFileItemTest;
     friend class KCoreDirListerCache;
@@ -593,6 +663,10 @@ public:
     /// Creates a new KFileItemList from a QList of file @p items.
     KFileItemList(const QList<KFileItem> &items);
 
+    /// Creates a new KFileItemList from an initializer_list of file @p items.
+    /// @since 5.76
+    KFileItemList(std::initializer_list<KFileItem> items);
+
     /**
      * Find a KFileItem by name and return it.
      * @return the item with the given name, or a null-item if none was found
@@ -617,8 +691,8 @@ public:
     // TODO KDE-5 add d pointer here so that we can merge KFileItemListProperties into KFileItemList
 };
 
-KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KFileItem &a);
-KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KFileItem &a);
+KIOCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KFileItem &a);
+KIOCORE_EXPORT QDataStream &operator>>(QDataStream &s, KFileItem &a);
 
 /**
  * Support for qDebug() << aFileItem
