@@ -1,28 +1,19 @@
-/* This file is part of the KDE project
-   Copyright (c) 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef knfsshare_h
 #define knfsshare_h
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include "kiocore_export.h"
 
+#include <memory>
+
 /**
  * @class KNFSShare knfsshare.h <KNFSShare>
  *
@@ -60,7 +51,7 @@ public:
      * Do not call!
      * The instance is destroyed automatically!
      */
-    virtual ~KNFSShare();
+    ~KNFSShare() override;
 
     /**
      * Returns the path to the used exports file,
@@ -77,9 +68,7 @@ Q_SIGNALS:
 private:
     KNFSShare();
     class KNFSSharePrivate;
-    KNFSSharePrivate *const d;
-
-    Q_PRIVATE_SLOT(d, void _k_slotFileChange(const QString &))
+    std::unique_ptr<KNFSSharePrivate> const d;
 
     friend class KNFSShareSingleton;
 };
