@@ -7,7 +7,6 @@
 
 #include "ksslsettings.h"
 
-
 #include <KConfigGroup>
 
 #include <QStandardPaths>
@@ -15,27 +14,30 @@
 class CipherNode
 {
 public:
-    CipherNode(const char *_name, int _keylen) :
-        name(QString::fromUtf8(_name)), keylen(_keylen) {}
+    CipherNode(const char *_name, int _keylen)
+        : name(QString::fromUtf8(_name))
+        , keylen(_keylen)
+    {
+    }
     QString name;
     int keylen;
-    inline int operator==(CipherNode &x)
+    inline int operator==(const CipherNode &x)
     {
-        return ((x.keylen == keylen) && (x.name == name));
+        return x.keylen == keylen && x.name == name;
     }
-    inline int operator< (CipherNode &x)
+    inline int operator<(const CipherNode &x)
     {
         return keylen < x.keylen;
     }
-    inline int operator<=(CipherNode &x)
+    inline int operator<=(const CipherNode &x)
     {
         return keylen <= x.keylen;
     }
-    inline int operator> (CipherNode &x)
+    inline int operator>(const CipherNode &x)
     {
         return keylen > x.keylen;
     }
-    inline int operator>=(CipherNode &x)
+    inline int operator>=(const CipherNode &x)
     {
         return keylen >= x.keylen;
     }
@@ -49,7 +51,6 @@ public:
     }
     ~KSSLSettingsPrivate()
     {
-
     }
 
     bool m_bUseEGD;
@@ -64,7 +65,7 @@ public:
 
     QStringList m_v3ciphers;
     QStringList m_v3selectedciphers;
-    QList<int>  m_v3bits;
+    QList<int> m_v3bits;
 };
 
 //
@@ -83,11 +84,10 @@ KSSLSettings::KSSLSettings(bool readConfig)
     }
 }
 
-// we don't save settings incase it was a temporary object
+// we don't save settings in case it was a temporary object
 KSSLSettings::~KSSLSettings()
 {
     delete d->m_cfg;
-    delete d;
 }
 
 QString KSSLSettings::getCipherList()
