@@ -13,45 +13,14 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <kprotocolmanager.h>
 #include <KSharedConfig>
+#include <kprotocolmanager.h>
 
-#include <kio/slaveconfig.h>
-#include "http_slave_defaults.h"
+#include "http_worker_defaults.h"
+#include "workerconfig.h"
 
 namespace KIO
 {
-
-/***************************** SessionData::AuthData ************************/
-#if 0
-struct SessionData::AuthData {
-
-public:
-    AuthData() {}
-
-    AuthData(const QByteArray &k, const QByteArray &g, bool p)
-    {
-        key = k;
-        group = g;
-        persist = p;
-    }
-
-    bool isKeyMatch(const QByteArray &val) const
-    {
-        return (val == key);
-    }
-
-    bool isGroupMatch(const QByteArray &val) const
-    {
-        return (val == group);
-    }
-
-    QByteArray key;
-    QByteArray group;
-    bool persist;
-};
-#endif
-
 /********************************* SessionData ****************************/
 
 class SessionData::SessionDataPrivate
@@ -72,19 +41,13 @@ public:
 SessionData::SessionData()
     : d(new SessionDataPrivate)
 {
-//  authData = 0;
 }
 
-SessionData::~SessionData()
-{
-    delete d;
-}
+SessionData::~SessionData() = default;
 
-void SessionData::configDataFor(MetaData &configData, const QString &proto,
-                                const QString &)
+void SessionData::configDataFor(MetaData &configData, const QString &proto, const QString &)
 {
-    if ((proto.startsWith(QLatin1String("http"), Qt::CaseInsensitive)) ||
-            (proto.startsWith(QLatin1String("webdav"), Qt::CaseInsensitive))) {
+    if ((proto.startsWith(QLatin1String("http"), Qt::CaseInsensitive)) || (proto.startsWith(QLatin1String("webdav"), Qt::CaseInsensitive))) {
         if (!d->initDone) {
             reset();
         }
@@ -116,9 +79,7 @@ void SessionData::reset()
 {
     d->initDone = true;
     // Get Cookie settings...
-    d->useCookie = KSharedConfig::openConfig(QStringLiteral("kcookiejarrc"), KConfig::NoGlobals)->
-                   group("Cookie Policy").
-                   readEntry("Cookies", true);
+    d->useCookie = KSharedConfig::openConfig(QStringLiteral("kcookiejarrc"), KConfig::NoGlobals)->group("Cookie Policy").readEntry("Cookies", true);
 
     d->language = KProtocolManager::acceptLanguagesHeader();
     d->charsets = QString::fromLatin1(QTextCodec::codecForLocale()->name()).toLower();
