@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_STOREDTRANSFERJOB
@@ -25,9 +13,10 @@
 
 namespace KIO
 {
-
 class StoredTransferJobPrivate;
 /**
+ * @class KIO::StoredTransferJob storedtransferjob.h <KIO/StoredTransferJob>
+ *
  * StoredTransferJob is a TransferJob (for downloading or uploading data) that
  * also stores a QByteArray with the data, making it simpler to use than the
  * standard TransferJob.
@@ -50,7 +39,7 @@ class KIOCORE_EXPORT StoredTransferJob : public KIO::TransferJob
     Q_OBJECT
 
 public:
-    ~StoredTransferJob();
+    ~StoredTransferJob() override;
 
     /**
      * Set data to be uploaded. This is for put jobs.
@@ -67,29 +56,27 @@ public:
 
 protected:
     StoredTransferJob(StoredTransferJobPrivate &dd);
-private:
-    Q_PRIVATE_SLOT(d_func(), void slotStoredData(KIO::Job *job, const QByteArray &data))
-    Q_PRIVATE_SLOT(d_func(), void slotStoredDataReq(KIO::Job *job, QByteArray &data))
 
+private:
     Q_DECLARE_PRIVATE(StoredTransferJob)
 };
 
 /**
- * Get (a.k.a. read), into a single QByteArray.
+ * Get (means: read), into a single QByteArray.
  * @see StoredTransferJob
  *
  * @param url the URL of the file
- * @param reload: Reload to reload the file, NoReload if it can be taken from the cache
+ * @param reload Reload to reload the file, NoReload if it can be taken from the cache
  * @param flags Can be HideProgressInfo here
  * @return the job handling the operation.
  */
 KIOCORE_EXPORT StoredTransferJob *storedGet(const QUrl &url, LoadType reload = NoReload, JobFlags flags = DefaultFlags);
 
 /**
- * Put (a.k.a. write) data from a QIODevice.
+ * Put (means: write) data from a QIODevice.
  * @see StoredTransferJob
  *
- * @param input The data to write, a device to read from. Must be open for reading.
+ * @param input The data to write, a device to read from. Must be open for reading (data will be read from the current position).
  * @param url Where to write data.
  * @param permissions May be -1. In this case no special permission mode is set.
  * @param flags Can be HideProgressInfo, Overwrite and Resume here. WARNING:
@@ -98,11 +85,10 @@ KIOCORE_EXPORT StoredTransferJob *storedGet(const QUrl &url, LoadType reload = N
  *
  * @since 5.10
  */
-KIOCORE_EXPORT StoredTransferJob *storedPut(QIODevice* input, const QUrl &url, int permissions,
-        JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StoredTransferJob *storedPut(QIODevice *input, const QUrl &url, int permissions, JobFlags flags = DefaultFlags);
 
 /**
- * Put (a.k.a. write) data from a single QByteArray.
+ * Put (means: write) data from a single QByteArray.
  * @see StoredTransferJob
  *
  * @param arr The data to write
@@ -112,11 +98,10 @@ KIOCORE_EXPORT StoredTransferJob *storedPut(QIODevice* input, const QUrl &url, i
  * Setting Resume means that the data will be appended to @p dest if @p dest exists.
  * @return the job handling the operation.
  */
-KIOCORE_EXPORT StoredTransferJob *storedPut(const QByteArray &arr, const QUrl &url, int permissions,
-        JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StoredTransferJob *storedPut(const QByteArray &arr, const QUrl &url, int permissions, JobFlags flags = DefaultFlags);
 
 /**
- * HTTP POST (a.k.a. write) data from a single QByteArray.
+ * HTTP POST (means: write) data from a single QByteArray.
  * @see StoredTransferJob
  *
  * @param arr The data to write
@@ -125,10 +110,9 @@ KIOCORE_EXPORT StoredTransferJob *storedPut(const QByteArray &arr, const QUrl &u
  * @return the job handling the operation.
  * @since 4.2
  */
-KIOCORE_EXPORT StoredTransferJob *storedHttpPost(const QByteArray &arr, const QUrl &url,
-        JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StoredTransferJob *storedHttpPost(const QByteArray &arr, const QUrl &url, JobFlags flags = DefaultFlags);
 /**
- * HTTP POST (a.k.a. write) data from the given IO device.
+ * HTTP POST (means: write) data from the given IO device.
  * @see StoredTransferJob
  *
  * @param device Device from which the encoded data to be posted is read. Must be open for reading.
@@ -139,8 +123,7 @@ KIOCORE_EXPORT StoredTransferJob *storedHttpPost(const QByteArray &arr, const QU
  *
  * @since 4.7
  */
-KIOCORE_EXPORT StoredTransferJob *storedHttpPost(QIODevice *device, const QUrl &url,
-        qint64 size = -1, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StoredTransferJob *storedHttpPost(QIODevice *device, const QUrl &url, qint64 size = -1, JobFlags flags = DefaultFlags);
 
 }
 
