@@ -103,10 +103,14 @@ public:
      */
     void dataReq();
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 103)
     /**
      * Call to signal that data from the sub-URL is needed
+     * @deprecated Since 5.96, feature no longer exists.
      */
+    KIOCORE_DEPRECATED_VERSION_BELATED(5, 103, 5, 96, "Feature no longer exists.")
     void needSubUrlData();
+#endif
 
     /**
      * Used to report the status of the worker.
@@ -209,14 +213,22 @@ public:
      * Type of message box. Should be kept in sync with KMessageBox::DialogType.
      */
     enum MessageBoxType {
-        QuestionYesNo = 1,
-        WarningYesNo = 2,
+        QuestionTwoActions = 1, ///< @since 5.100
+        WarningTwoActions = 2, ///< @since 5.100
         WarningContinueCancel = 3,
-        WarningYesNoCancel = 4,
+        WarningTwoActionsCancel = 4, ///< @since 5.100
         Information = 5,
         SSLMessageBox = 6,
-        // In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionYesNoCancel = 9
+        // In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionTwoActionsCancel = 9
         WarningContinueCancelDetailed = 10,
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 100)
+        QuestionYesNo ///< @deprecated Since 5.100, use QuestionTwoActions.
+            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use QuestionTwoActions.") = QuestionTwoActions,
+        WarningYesNo ///< @deprecated Since 5.100, use WarningTwoActions.
+            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use WarningTwoActions.") = WarningTwoActions,
+        WarningYesNoCancel ///< @deprecated Since 5.100, use WarningTwoActionsCancel.
+            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use WarningTwoActionsCancel.") = WarningTwoActionsCancel,
+#endif
     };
 
     /**
@@ -225,49 +237,57 @@ public:
     enum ButtonCode {
         Ok = 1,
         Cancel = 2,
-        Yes = 3,
-        No = 4,
+        PrimaryAction = 3, ///< @since 5.100
+        SecondaryAction = 4, ///< @since 5.100
         Continue = 5,
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 100)
+        Yes ///< @deprecated Since 5.100, use PrimaryAction.
+            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use PrimaryAction.") = PrimaryAction,
+        No ///< @deprecated Since 5.100, use SecondaryAction.
+            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use SecondaryAction.") = SecondaryAction,
+#endif
     };
 
     /**
      * Call this to show a message box from the worker
-     * @param type type of message box: QuestionYesNo, WarningYesNo, WarningContinueCancel...
+     * @param type type of message box
      * @param text Message string. May contain newlines.
      * @param title Message box title.
-     * @param buttonYes The text for the first button.
-     *                  The default is i18n("&Yes").
-     * @param buttonNo  The text for the second button.
-     *                  The default is i18n("&No").
-     * Note: for ContinueCancel, buttonYes is the continue button and buttonNo is unused.
-     *       and for Information, none is used.
+     * @param primaryActionText the text for the first button.
+     *                          Ignored for @p type Information & SSLMessageBox.
+     *                          The (deprecated since 5.100) default is i18n("&Yes").
+     * @param secondaryActionText the text for the second button.
+     *                            Ignored for @p type WarningContinueCancel, WarningContinueCancelDetailed,
+     *                            Information & SSLMessageBox.
+     *                            The (deprecated since 5.100) default is i18n("&No").
      * @return a button code, as defined in ButtonCode, or 0 on communication error.
      */
     int messageBox(MessageBoxType type,
                    const QString &text,
                    const QString &title = QString(),
-                   const QString &buttonYes = QString(),
-                   const QString &buttonNo = QString());
+                   const QString &primaryActionText = QString(),
+                   const QString &secondaryActionText = QString());
 
     /**
      * Call this to show a message box from the worker
      * @param text Message string. May contain newlines.
-     * @param type type of message box: QuestionYesNo, WarningYesNo, WarningContinueCancel...
+     * @param type type of message box
      * @param title Message box title.
-     * @param buttonYes The text for the first button.
-     *                  The default is i18n("&Yes").
-     * @param buttonNo  The text for the second button.
-     *                  The default is i18n("&No").
-     * Note: for ContinueCancel, buttonYes is the continue button and buttonNo is unused.
-     *       and for Information, none is used.
+     * @param primaryActionText the text for the first button.
+     *                          Ignored for @p type Information & SSLMessageBox.
+     *                          The (deprecated since 5.100) default is i18n("&Yes").
+     * @param secondaryActionText the text for the second button.
+     *                            Ignored for @p type WarningContinueCancel, WarningContinueCancelDetailed,
+     *                            Information & SSLMessageBox.
+     *                            The (deprecated since 5.100) default is i18n("&No").
      * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
      * @return a button code, as defined in ButtonCode, or 0 on communication error.
      */
     int messageBox(const QString &text,
                    MessageBoxType type,
                    const QString &title = QString(),
-                   const QString &buttonYes = QString(),
-                   const QString &buttonNo = QString(),
+                   const QString &primaryActionText = QString(),
+                   const QString &secondaryActionText = QString(),
                    const QString &dontAskAgainName = QString());
 
     /**
@@ -772,7 +792,7 @@ public:
      *
      * \code
      * AuthInfo info;
-     * info.url = QUrl("http://www.foobar.org/foo/bar");
+     * info.url = QUrl("https://www.foobar.org/foo/bar");
      * info.username = "somename";
      * info.verifyPath = true;
      * if ( !checkCachedAuthentication( info ) )
@@ -797,7 +817,7 @@ public:
      *
      * \code
      * AuthInfo info;
-     * info.url = QUrl("http://www.foobar.org/foo/bar");
+     * info.url = QUrl("https://www.foobar.org/foo/bar");
      * info.username = "somename";
      * info.verifyPath = true;
      * if ( !checkCachedAuthentication( info ) ) {
