@@ -16,10 +16,9 @@
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KCharsets>
-#include <krecentdocument.h>
 #include <KSharedConfig>
 #include <KWindowConfig>
+#include <krecentdocument.h>
 
 #include <QBoxLayout>
 #include <QComboBox>
@@ -29,7 +28,8 @@
 struct KEncodingFileDialogPrivate {
     KEncodingFileDialogPrivate()
         : cfgGroup(KSharedConfig::openConfig(), ConfigGroup)
-    {}
+    {
+    }
 
     QComboBox *encoding;
     KFileWidget *w;
@@ -37,11 +37,11 @@ struct KEncodingFileDialogPrivate {
 };
 
 KEncodingFileDialog::KEncodingFileDialog(const QUrl &startDir,
-        const QString &encoding,
-        const QString &filter,
-        const QString &caption,
-        QFileDialog::AcceptMode type,
-        QWidget *parent)
+                                         const QString &encoding,
+                                         const QString &filter,
+                                         const QString &title,
+                                         QFileDialog::AcceptMode type,
+                                         QWidget *parent)
     : QDialog(parent, Qt::Dialog)
     , d(new KEncodingFileDialogPrivate)
 {
@@ -53,8 +53,8 @@ KEncodingFileDialog::KEncodingFileDialog(const QUrl &startDir,
         d->w->setOperationMode(KFileWidget::Saving);
     }
 
-    setWindowTitle(caption);
-    //ops->clearHistory();
+    setWindowTitle(title);
+    // ops->clearHistory();
 
     KWindowConfig::restoreWindowSize(windowHandle(), d->cfgGroup);
 
@@ -71,22 +71,22 @@ KEncodingFileDialog::KEncodingFileDialog(const QUrl &startDir,
     d->w->setCustomWidget(i18n("Encoding:"), d->encoding);
 
     d->encoding->clear();
-    QString sEncoding = encoding;
-    QString systemEncoding = QLatin1String(QTextCodec::codecForLocale()->name());
-    if (sEncoding.isEmpty() || sEncoding == QLatin1String("System")) {
+    QByteArray sEncoding = encoding.toUtf8();
+    auto systemEncoding = QTextCodec::codecForLocale()->name();
+    if (sEncoding.isEmpty() || sEncoding == "System") {
         sEncoding = systemEncoding;
     }
 
-    const QStringList encodings(KCharsets::charsets()->availableEncodingNames());
-    int insert = 0, system = 0;
+    const auto encodings = QTextCodec::availableCodecs();
+    int insert = 0;
+    int system = 0;
     bool foundRequested = false;
-    for (const QString &encoding : encodings) {
-        bool found = false;
-        QTextCodec *codecForEnc = KCharsets::charsets()->codecForName(encoding, found);
+    for (const auto &encoding : encodings) {
+        QTextCodec *codecForEnc = QTextCodec::codecForName(encoding);
 
-        if (found) {
-            d->encoding->addItem(encoding);
-            const QString codecName = QLatin1String(codecForEnc->name());
+        if (codecForEnc) {
+            d->encoding->addItem(QString::fromUtf8(encoding));
+            auto codecName = codecForEnc->name();
             if ((codecName == sEncoding) || (encoding == sEncoding)) {
                 d->encoding->setCurrentIndex(insert);
                 foundRequested = true;
@@ -104,10 +104,7 @@ KEncodingFileDialog::KEncodingFileDialog(const QUrl &startDir,
     }
 }
 
-KEncodingFileDialog::~KEncodingFileDialog()
-{
-    delete d;
-}
+KEncodingFileDialog::~KEncodingFileDialog() = default;
 
 QString KEncodingFileDialog::selectedEncoding() const
 {
@@ -118,15 +115,10 @@ QString KEncodingFileDialog::selectedEncoding() const
     }
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNameAndEncoding(const QString &encoding,
-        const QUrl &startDir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getOpenFileNameAndEncoding(const QString &encoding, const QUrl &startDir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(startDir, encoding, filter,
-                            caption.isNull() ? i18n("Open") : caption,
-                            QFileDialog::AcceptOpen, parent);
+    KEncodingFileDialog dlg(startDir, encoding, filter, title.isNull() ? i18n("Open") : title, QFileDialog::AcceptOpen, parent);
 
     dlg.d->w->setMode(KFile::File | KFile::LocalOnly);
     dlg.exec();
@@ -137,15 +129,10 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNameAndEncoding(cons
     return res;
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNamesAndEncoding(const QString &encoding,
-        const QUrl &startDir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getOpenFileNamesAndEncoding(const QString &encoding, const QUrl &startDir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(startDir, encoding, filter,
-                            caption.isNull() ? i18n("Open") : caption,
-                            QFileDialog::AcceptOpen, parent);
+    KEncodingFileDialog dlg(startDir, encoding, filter, title.isNull() ? i18n("Open") : title, QFileDialog::AcceptOpen, parent);
     dlg.d->w->setMode(KFile::Files | KFile::LocalOnly);
     dlg.exec();
 
@@ -155,15 +142,10 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenFileNamesAndEncoding(con
     return res;
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlAndEncoding(const QString &encoding,
-        const QUrl &startDir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getOpenUrlAndEncoding(const QString &encoding, const QUrl &startDir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(startDir, encoding, filter,
-                            caption.isNull() ? i18n("Open") : caption,
-                            QFileDialog::AcceptOpen, parent);
+    KEncodingFileDialog dlg(startDir, encoding, filter, title.isNull() ? i18n("Open") : title, QFileDialog::AcceptOpen, parent);
 
     dlg.d->w->setMode(KFile::File);
     dlg.exec();
@@ -174,15 +156,10 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlAndEncoding(const QSt
     return res;
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlsAndEncoding(const QString &encoding,
-        const QUrl &startDir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getOpenUrlsAndEncoding(const QString &encoding, const QUrl &startDir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(startDir, encoding, filter,
-                            caption.isNull() ? i18n("Open") : caption,
-                            QFileDialog::AcceptOpen, parent);
+    KEncodingFileDialog dlg(startDir, encoding, filter, title.isNull() ? i18n("Open") : title, QFileDialog::AcceptOpen, parent);
 
     dlg.d->w->setMode(KFile::Files);
     dlg.exec();
@@ -193,15 +170,10 @@ KEncodingFileDialog::Result KEncodingFileDialog::getOpenUrlsAndEncoding(const QS
     return res;
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getSaveFileNameAndEncoding(const QString &encoding,
-        const QUrl &dir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getSaveFileNameAndEncoding(const QString &encoding, const QUrl &dir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(dir, encoding, filter,
-                            caption.isNull() ? i18n("Save As") : caption,
-                            QFileDialog::AcceptSave, parent);
+    KEncodingFileDialog dlg(dir, encoding, filter, title.isNull() ? i18n("Save As") : title, QFileDialog::AcceptSave, parent);
     dlg.d->w->setMode(KFile::File);
     dlg.exec();
 
@@ -216,15 +188,10 @@ KEncodingFileDialog::Result KEncodingFileDialog::getSaveFileNameAndEncoding(cons
     return res;
 }
 
-KEncodingFileDialog::Result KEncodingFileDialog::getSaveUrlAndEncoding(const QString &encoding,
-        const QUrl &dir,
-        const QString &filter,
-        QWidget *parent,
-        const QString &caption)
+KEncodingFileDialog::Result
+KEncodingFileDialog::getSaveUrlAndEncoding(const QString &encoding, const QUrl &dir, const QString &filter, QWidget *parent, const QString &title)
 {
-    KEncodingFileDialog dlg(dir, encoding, filter,
-                            caption.isNull() ? i18n("Save As") : caption,
-                            QFileDialog::AcceptSave, parent);
+    KEncodingFileDialog dlg(dir, encoding, filter, title.isNull() ? i18n("Save As") : title, QFileDialog::AcceptSave, parent);
     dlg.d->w->setMode(KFile::File);
 
     Result res;
