@@ -39,6 +39,9 @@ KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &addre
     , m_isCdrom(false)
     , m_isAccessible(false)
     , m_isTeardownAllowed(false)
+    , m_isTeardownOverlayRecommended(false)
+    , m_isTeardownInProgress(false)
+    , m_isSetupInProgress(false)
 {
     updateDeviceInfo(udi);
     setBookmark(m_manager->findByAddress(address));
@@ -118,11 +121,34 @@ bool KFilePlacesItem::isDevice() const
     return !bookmark().metaDataItem(QStringLiteral("UDI")).isEmpty();
 }
 
+KFilePlacesModel::DeviceAccessibility KFilePlacesItem::deviceAccessibility() const
+{
+    if (m_isTeardownInProgress) {
+        return KFilePlacesModel::TeardownInProgress;
+    } else if (m_isSetupInProgress) {
+        return KFilePlacesModel::SetupInProgress;
+    } else if (m_isAccessible) {
+        return KFilePlacesModel::Accessible;
+    } else {
+        return KFilePlacesModel::SetupNeeded;
+    }
+}
+
 bool KFilePlacesItem::isTeardownAllowed() const
 {
     return m_isTeardownAllowed;
 }
 
+bool KFilePlacesItem::isTeardownOverlayRecommended() const
+{
+    return m_isTeardownOverlayRecommended;
+}
+
+bool KFilePlacesItem::isEjectAllowed() const
+{
+    return m_isCdrom;
+}
+
 KBookmark KFilePlacesItem::bookmark() const
 {
     return m_bookmark;
@@ -278,7 +304,10 @@ QVariant KFilePlacesItem::deviceData(int role) const
     if (d.isValid()) {
         switch (role) {
         case Qt::DisplayRole:
-            return d.displayName();
+            if (m_deviceDisplayName.isEmpty()) {
+                m_deviceDisplayName = d.displayName();
+            }
+            return m_deviceDisplayName;
         case Qt::DecorationRole:
             // qDebug() << "adding emblems" << m_emblems << "to device icon" << m_deviceIconName;
             return KIconUtils::addOverlays(m_deviceIconName, m_emblems);
@@ -319,6 +348,15 @@ QVariant KFilePlacesItem::deviceData(int role) const
                 return QVariant();
             }
 
+        case KFilePlacesModel::EjectAllowedRole:
+            return m_isAccessible && m_isCdrom;
+
+        case KFilePlacesModel::TeardownOverlayRecommendedRole:
+            return m_isTeardownOverlayRecommended;
+
+        case KFilePlacesModel::DeviceAccessibilityRole:
+            return deviceAccessibility();
+
         case KFilePlacesModel::FixedDeviceRole: {
             if (m_drive != nullptr) {
                 return !m_drive->isHotpluggable() && !m_drive->isRemovable();
@@ -327,7 +365,7 @@ QVariant KFilePlacesItem::deviceData(int role) const
         }
 
         case KFilePlacesModel::CapacityBarRecommendedRole:
-            return m_isAccessible && !m_isCdrom;
+            return m_isAccessible && !m_isCdrom && !m_networkShare;
 
         case KFilePlacesModel::IconNameRole:
             return m_deviceIconName;
@@ -446,6 +484,24 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
         }
 
         if (m_access) {
+            connect(m_access.data(), &Solid::StorageAccess::setupRequested, this, [this] {
+                m_isSetupInProgress = true;
+                Q_EMIT itemChanged(id(), {KFilePlacesModel::DeviceAccessibilityRole});
+            });
+            connect(m_access.data(), &Solid::StorageAccess::setupDone, this, [this] {
+                m_isSetupInProgress = false;
+                Q_EMIT itemChanged(id(), {KFilePlacesModel::DeviceAccessibilityRole});
+            });
+
+            connect(m_access.data(), &Solid::StorageAccess::teardownRequested, this, [this] {
+                m_isTeardownInProgress = true;
+                Q_EMIT itemChanged(id(), {KFilePlacesModel::DeviceAccessibilityRole});
+            });
+            connect(m_access.data(), &Solid::StorageAccess::teardownDone, this, [this] {
+                m_isTeardownInProgress = false;
+                Q_EMIT itemChanged(id(), {KFilePlacesModel::DeviceAccessibilityRole});
+            });
+
             connect(m_access.data(), &Solid::StorageAccess::accessibilityChanged, this, &KFilePlacesItem::onAccessibilityChanged);
             onAccessibilityChanged(m_access->isAccessible());
         }
@@ -482,6 +538,13 @@ void KFilePlacesItem::onAccessibilityChanged(bool isAccessible)
         }
     }
 
+    m_isTeardownOverlayRecommended = m_isTeardownAllowed && !m_networkShare;
+    if (m_isTeardownOverlayRecommended) {
+        if (m_drive && !m_drive->isHotpluggable() && !m_drive->isRemovable()) {
+            m_isTeardownOverlayRecommended = false;
+        }
+    }
+
     Q_EMIT itemChanged(id());
 }
 
