@@ -120,6 +120,11 @@ Q_SIGNALS:
      */
     void processStarted(qint64 pid);
 
+    /**
+     * @brief emitted when the process was finished
+     */
+    void processFinished();
+
     /**
      * Notifies about having received the token were waiting for.
      *
@@ -135,12 +140,15 @@ protected:
     void setPid(qint64 pid);
     void terminateStartupNotification();
     QString name() const;
+    QString maybeAliasedName(const QString &pattern) const;
+    static QString escapeUnitName(const QString &input);
 
     std::unique_ptr<KProcess> m_process;
     QString m_executable; // can be a full path
     QString m_desktopName;
     QString m_desktopFilePath;
     QString m_description;
+    QString m_cmd;
     qint64 m_pid = 0;
     KService::Ptr m_service;
     QString m_serviceEntryPath;
