@@ -11,6 +11,7 @@
 #include <KDEDModule>
 #include <QList>
 #include <QVariant>
+#include <memory>
 class QString;
 class QSslCertificate;
 
@@ -22,7 +23,7 @@ class KSSLD : public KDEDModule
     Q_OBJECT
 public:
     KSSLD(QObject *parent, const QVariantList &);
-    ~KSSLD();
+    ~KSSLD() override;
 
     void setRule(const KSslCertificateRule &rule);
     void clearRule(const KSslCertificateRule &rule);
@@ -31,9 +32,9 @@ public:
     KSslCertificateRule rule(const QSslCertificate &cert, const QString &hostName) const;
 
 private:
-    //AFAICS we don't need the d-pointer technique here but it makes the code look
-    //more like the rest of kdelibs and it can be reused anywhere in kdelibs.
-    KSSLDPrivate *const d;
+    // AFAICS we don't need the d-pointer technique here but it makes the code look
+    // more like the rest of kdelibs and it can be reused anywhere in kdelibs.
+    std::unique_ptr<KSSLDPrivate> const d;
 };
 
-#endif //KSSLD_H
+#endif // KSSLD_H
