@@ -9,7 +9,7 @@
 */
 
 #include "kshorturifilter.h"
-#include "../pathhelpers_p.h" // concatPaths(), isAbsoluteLocalPath()
+#include "../utils_p.h"
 
 #include <QDBusConnection>
 #include <QDir>
@@ -124,7 +124,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
 
     // Replicate what KUrl(cmd) did in KDE4. This could later be folded into the checks further down...
     QUrl url;
-    if (isAbsoluteLocalPath(cmd)) {
+    if (Utils::isAbsoluteLocalPath(cmd)) {
         url = QUrl::fromLocalFile(cmd);
     } else {
         url.setUrl(cmd);
@@ -202,7 +202,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
     QString query;
     QString nameFilter;
 
-    if (!isAbsoluteLocalPath(cmd) && QUrl(cmd).isRelative()) {
+    if (!Utils::isAbsoluteLocalPath(cmd) && QUrl(cmd).isRelative()) {
         path = cmd;
         qCDebug(category) << "path=cmd=" << path;
     } else {
@@ -282,7 +282,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         }
     }
 
-    bool isLocalFullPath = isAbsoluteLocalPath(path);
+    bool isLocalFullPath = Utils::isAbsoluteLocalPath(path);
 
     // Checking for local resource match...
     // Determine if "uri" is an absolute path to a local resource  OR
@@ -356,7 +356,7 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         }
 
         // Can be abs path to file or directory, or to executable with args
-        bool isDir = ((buff.st_mode & QT_STAT_MASK) == QT_STAT_DIR);
+        bool isDir = Utils::isDirMask(buff.st_mode);
         if (!isDir && access(QFile::encodeName(path).data(), X_OK) == 0) {
             qCDebug(category) << "Abs path to EXECUTABLE";
             setFilteredUri(data, u);
@@ -365,10 +365,10 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
         }
 
         // Open "uri" as file:/xxx if it is a non-executable local resource.
-        if (isDir || ((buff.st_mode & QT_STAT_MASK) == QT_STAT_REG)) {
+        if (isDir || Utils::isRegFileMask(buff.st_mode)) {
             qCDebug(category) << "Abs path as local file or directory";
             if (!nameFilter.isEmpty()) {
-                u.setPath(concatPaths(u.path(), nameFilter));
+                u.setPath(Utils::concatPaths(u.path(), nameFilter));
             }
             setFilteredUri(data, u);
             setUriType(data, (isDir) ? KUriFilterData::LocalDir : KUriFilterData::LocalFile);
@@ -423,9 +423,9 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
             qCDebug(category) << "testing regexp for" << hint.prepend;
             if (hint.hintRe.match(cmd).capturedStart() == 0) {
                 const QString cmdStr = hint.prepend + cmd;
-                QUrl url(cmdStr);
-                qCDebug(category) << "match - prepending" << hint.prepend << "->" << cmdStr << "->" << url;
-                setFilteredUri(data, url);
+                QUrl cmdUrl(cmdStr);
+                qCDebug(category) << "match - prepending" << hint.prepend << "->" << cmdStr << "->" << cmdUrl;
+                setFilteredUri(data, cmdUrl);
                 setUriType(data, hint.type);
                 return true;
             }
@@ -448,11 +448,11 @@ bool KShortUriFilter::filterUri(KUriFilterData &data) const
             }
             urlStr += cmd;
 
-            QUrl url(urlStr);
-            if (url.isValid()) {
-                setFilteredUri(data, url);
+            QUrl fixedUrl(urlStr);
+            if (fixedUrl.isValid()) {
+                setFilteredUri(data, fixedUrl);
                 setUriType(data, KUriFilterData::NetProtocol);
-            } else if (isKnownProtocol(url.scheme())) {
+            } else if (isKnownProtocol(fixedUrl.scheme())) {
                 setFilteredUri(data, data.uri());
                 setUriType(data, KUriFilterData::Error);
             }
