@@ -11,7 +11,6 @@
 #include "accessmanager.h"
 #include "job.h"
 #include "kio_widgets_debug.h"
-#include "scheduler.h"
 
 #include <kprotocolinfo.h>
 #include <kurlauthorized.h>
@@ -218,7 +217,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
             }
 
             const auto headerName = QStringView(httpHeader).left(index);
-            // Ignore cookie header since it is handled by the http ioslave.
+            // Ignore cookie header since it is handled by the http KIO worker.
             if (headerName.startsWith(QLatin1String("set-cookie"), Qt::CaseInsensitive)) {
                 continue;
             }
