@@ -25,7 +25,6 @@ class QLabel;
 
 namespace KDEPrivate
 {
-
 /**
  * 'General' plugin
  *  This plugin displays the name of the file, its size and access times.
@@ -39,7 +38,7 @@ public:
      * Constructor
      */
     explicit KFilePropsPlugin(KPropertiesDialog *_props);
-    virtual ~KFilePropsPlugin();
+    ~KFilePropsPlugin() override;
 
     /**
      * Applies all changes made.  This plugin must be always the first
@@ -72,7 +71,8 @@ protected Q_SLOTS:
     void slotSizeDetails();
 
 Q_SIGNALS:
-    void leaveModality();
+    void changesApplied();
+
 private Q_SLOTS:
     void nameFileChanged(const QString &text);
     void slotIconChanged();
@@ -81,9 +81,10 @@ private:
     bool enableIconButton() const;
     void determineRelativePath(const QString &path);
     void applyIconChanges();
+    void updateDefaultHandler(const QString &mimeType);
 
     class KFilePropsPluginPrivate;
-    KFilePropsPluginPrivate *const d;
+    std::unique_ptr<KFilePropsPluginPrivate> d;
 };
 
 /**
@@ -100,20 +101,20 @@ public:
         PermissionsOnlyFiles = 0,
         PermissionsOnlyDirs = 1,
         PermissionsOnlyLinks = 2,
-        PermissionsMixed = 3
+        PermissionsMixed = 3,
     };
 
     enum PermissionsTarget {
-        PermissionsOwner  = 0,
-        PermissionsGroup  = 1,
-        PermissionsOthers = 2
+        PermissionsOwner = 0,
+        PermissionsGroup = 1,
+        PermissionsOthers = 2,
     };
 
     /**
      * Constructor
      */
     explicit KFilePermissionsPropsPlugin(KPropertiesDialog *_props);
-    virtual ~KFilePermissionsPropsPlugin();
+    ~KFilePermissionsPropsPlugin() override;
 
     void applyChanges() override;
 
@@ -123,32 +124,25 @@ public:
     static bool supports(const KFileItemList &_items);
 
 private Q_SLOTS:
-
-    void slotChmodResult(KJob *);
     void slotShowAdvancedPermissions();
 
 Q_SIGNALS:
-    void leaveModality();
+    void changesApplied();
 
 private:
-    void setComboContent(QComboBox *combo, PermissionsTarget target,
-                         mode_t permissions, mode_t partial);
+    void setComboContent(QComboBox *combo, PermissionsTarget target, mode_t permissions, mode_t partial);
     bool isIrregular(mode_t permissions, bool isDir, bool isLink);
     void enableAccessControls(bool enable);
     void updateAccessControls();
-    void getPermissionMasks(mode_t &andFilePermissions,
-                            mode_t &andDirPermissions,
-                            mode_t &orFilePermissions,
-                            mode_t &orDirPermissions);
+    void getPermissionMasks(mode_t &andFilePermissions, mode_t &andDirPermissions, mode_t &orFilePermissions, mode_t &orDirPermissions);
 
     static const mode_t permissionsMasks[3];
     static const mode_t standardPermissions[4];
-    static const char *const permissionsTexts[4][4];
 
     static const mode_t fperm[3][4];
 
     class KFilePermissionsPropsPluginPrivate;
-    KFilePermissionsPropsPluginPrivate *const d;
+    std::unique_ptr<KFilePermissionsPropsPluginPrivate> d;
 };
 
 class KChecksumsPlugin : public KPropertiesDialogPlugin
@@ -156,7 +150,7 @@ class KChecksumsPlugin : public KPropertiesDialogPlugin
     Q_OBJECT
 public:
     explicit KChecksumsPlugin(KPropertiesDialog *dialog);
-    virtual ~KChecksumsPlugin();
+    ~KChecksumsPlugin() override;
 
     static bool supports(const KFileItemList &items);
 
@@ -190,7 +184,7 @@ private:
     void cacheChecksum(const QString &checksum, QCryptographicHash::Algorithm algorithm);
 
     class KChecksumsPluginPrivate;
-    KChecksumsPluginPrivate *const d;
+    std::unique_ptr<KChecksumsPluginPrivate> d;
 };
 
 /**
@@ -209,7 +203,7 @@ public:
      * Constructor
      */
     explicit KUrlPropsPlugin(KPropertiesDialog *_props);
-    virtual ~KUrlPropsPlugin();
+    ~KUrlPropsPlugin() override;
 
     void applyChanges() override;
 
@@ -219,36 +213,7 @@ public:
 
 private:
     class KUrlPropsPluginPrivate;
-    KUrlPropsPluginPrivate *const d;
-};
-
-/**
- * Properties plugin for device .desktop files
- * @internal
- */
-class KDevicePropsPlugin : public KPropertiesDialogPlugin
-{
-    Q_OBJECT
-public:
-    explicit KDevicePropsPlugin(KPropertiesDialog *_props);
-    virtual ~KDevicePropsPlugin();
-
-    void applyChanges() override;
-
-    static bool supports(const KFileItemList &_items);
-
-private Q_SLOTS:
-    void slotActivated(int);
-    void slotDeviceChanged();
-    void slotFoundMountPoint(const QString &mp, quint64 kibSize,
-                             quint64 kibUsed, quint64 kibAvail);
-
-private:
-    void updateInfo();
-
-private:
-    class KDevicePropsPluginPrivate;
-    KDevicePropsPluginPrivate *const d;
+    std::unique_ptr<KUrlPropsPluginPrivate> d;
 };
 
 /**
@@ -267,7 +232,7 @@ public:
      * Constructor
      */
     explicit KDesktopPropsPlugin(KPropertiesDialog *_props);
-    virtual ~KDesktopPropsPlugin();
+    ~KDesktopPropsPlugin() override;
 
     void applyChanges() override;
 
@@ -284,7 +249,7 @@ private:
 
 private:
     class KDesktopPropsPluginPrivate;
-    KDesktopPropsPluginPrivate *const d;
+    std::unique_ptr<KDesktopPropsPluginPrivate> d;
 };
 
 }
